@@ -6,7 +6,7 @@ use CHI::Util qw(require_dynamic);
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.091';
 
 our $Logger = CHI::NullLogger->new();    ## no critic
 
@@ -158,13 +158,22 @@ the namespace to the current component path.
 
 Defaults to 'Default' if not specified.
 
-=item serializer [OBJECT]
+=item serializer [STRING|OBJECT]
 
 An object to use for serializing data before storing it in the cache, and deserializing
-data before retrieving it from the cache. Must be a L<Data::Serializer|Data::Serializer>
-object, or another object that implements I<serialize()> and I<deserialize()>. e.g.
+data before retrieving it from the cache.
 
-    my $cache = CHI->new(serializer => Data::Serializer->new(serializer => 'Data::Dumper', compress => 1);
+If this is a string, a L<Data::Serializer|Data::Serializer> object will be created, with
+the string passed as the 'serializer' option. Common options include 'Storable',
+'Data::Dumper', and 'YAML'.
+
+Otherwise, this must be a L<Data::Serializer|Data::Serializer> object, or another object
+that implements I<serialize()> and I<deserialize()>.
+
+e.g.
+
+    my $cache = CHI->new(serializer => 'Data::Dumper');
+    my $cache = CHI->new(serializer => Data::Serializer->new(serializer => 'Data::Dumper', compress => 1));
 
 The default is to use plain Storable.
 
@@ -615,9 +624,10 @@ Bugs and feature requests will be tracked at RT:
 
     http://rt.cpan.org/NoAuth/Bugs.html?Dist=CHI
 
-The latest source code is available at:
+The latest source code can be browsed and fetched at:
 
-    http://code.google.com/p/perl-cache/wiki/Source
+    http://github.com/jonswar/perl-chi/tree/master
+    git clone git://github.com/jonswar/perl-chi.git
 
 =head1 TODO
 
