@@ -1,5 +1,6 @@
 package CHI::Driver::Memory;
 use Moose;
+use MooseX::AttributeHelpers;
 use strict;
 use warnings;
 
@@ -7,53 +8,35 @@ extends 'CHI::Driver';
 
 my $Default_Datastore = {};
 
-has 'datastore' =>
-  ( is => 'ro', isa => 'HashRef', default => sub { $Default_Datastore } );
+has 'datastore' => (
+    metaclass => 'Collection::Hash',
+    is        => 'ro',
+    isa       => 'HashRef',
+    default   => sub { $Default_Datastore },
+    provides  => { keys => 'get_namespaces' },
+);
+
+has 'datastore_for_namespace' => (
+    metaclass => 'Collection::Hash',
+    is        => 'ro',
+    isa       => 'HashRef',
+    lazy      => 1,
+    builder   => '_build_datastore_for_namespace',
+    provides  => {
+        get    => 'fetch',
+        set    => 'store',
+        delete => 'remove',
+        clear  => 'clear',
+        keys   => 'get_keys',
+    },
+);
 
 __PACKAGE__->meta->make_immutable();
 
-sub BUILD {
-    my ( $self, $params ) = @_;
-
-    $self->{datastore}->{ $self->namespace } ||= {};
-    $self->{datastore_for_namespace} = $self->{datastore}->{ $self->namespace };
-}
-
-sub fetch {
-    my ( $self, $key ) = @_;
-
-    return $self->{datastore_for_namespace}->{$key};
-}
-
-sub store {
-    my ( $self, $key, $data ) = @_;
-
-    $self->{datastore_for_namespace}->{$key} = $data;
-}
-
-sub remove {
-    my ( $self, $key ) = @_;
-
-    delete $self->{datastore_for_namespace}->{$key};
-}
-
-sub clear {
+sub _build_datastore_for_namespace {
     my ($self) = @_;
 
-    $self->{datastore_for_namespace} =
-      $self->{datastore}->{ $self->namespace } = {};
-}
-
-sub get_keys {
-    my ($self) = @_;
-
-    return keys( %{ $self->{datastore_for_namespace} } );
-}
-
-sub get_namespaces {
-    my ($self) = @_;
-
-    return keys( %{ $self->{datastore} } );
+    return $self->datastore->{ $self->namespace } ||= {};
 }
 
 1;
