@@ -449,7 +449,8 @@ sub test_serializers : Tests {
 
     my $cache1 = $self->new_cache();
     isa_ok( $cache1->serializer, 'Data::Serializer' );
-    is( $cache1->serializer->serializer, 'Storable' );
+    is( $cache1->serializer->serializer,
+        'Storable', 'default serializer is storable' );
     my $cache2 = $self->new_cache();
     is( $cache1->serializer, $cache2->serializer,
         'same serializer returned from two objects' );
@@ -467,29 +468,28 @@ sub test_serializers : Tests {
         "valid dummy serializer"
     );
 
-    my @variants = (
-        { serializer => 'Storable' },
-        { serializer => 'Data::Dumper' },
-        { serializer => 'YAML' },
-    );
-    @variants = grep { check_install( module => $_->{serializer} ) } @variants;
+    my @variants = (qw(Storable Data::Dumper YAML));
+    @variants = grep { check_install( module => $_ ) } @variants;
     ok( scalar(@variants), "some variants ok" );
-    foreach my $variant (@variants) {
-        my $serializer = Data::Serializer->new(%$variant);
-        my $cache = $self->new_cache( serializer => $serializer );
-        is(
-            $cache->serializer->serializer,
-            $variant->{serializer},
-            "serializer = " . $variant->{serializer}
-        );
-        $self->{cache} = $cache;
-        $self->test_key_types();
+    foreach my $mode (qw(string object)) {
+        foreach my $variant (@variants) {
+            my $serializer_param = (
+                  $mode eq 'string'
+                ? $variant
+                : Data::Serializer->new( serializer => $variant )
+            );
+            my $cache = $self->new_cache( serializer => $serializer_param );
+            is( $cache->serializer->serializer,
+                $variant, "serializer = " . $variant );
+            $self->{cache} = $cache;
+            $self->test_key_types();
+        }
     }
 
     my $initial_count        = 6;
     my $test_key_types_count = $self->{key_count} * 6 + 1;
-    $self->num_tests(
-        $initial_count + scalar(@variants) * ( 1 + $test_key_types_count ) );
+    $self->num_tests( $initial_count +
+          scalar(@variants) * 2 * ( 1 + $test_key_types_count ) );
 }
 
 sub test_namespaces : Test(12) {
